SigningKey

Struct SigningKey 

pub struct SigningKey {
    pub(crate) inner: PrivateKey,
}

Fields

inner: PrivateKey

Implementations

Source

impl SigningKey

pub fn into_inner(self) -> PrivateKey

pub fn random<R: CryptoRngCore>(rng: R) -> Self

Generates a fresh, cryptographically random signing key using rng.

pub fn read_from_file_unencrypted<P: AsRef<Path>>( path: P, ) -> Result<Self, SigningKeyError>

pub fn read_from_file_encrypted<P: AsRef<Path>>( path: P, passphrase: SecretString, ) -> Result<Self, SigningKeyError>

Reads a passphrase-encrypted signing key from path.

The file is expected to be an age payload produced via passphrase encryption (e.g. age -p) whose plaintext is the raw encoded ed25519 private key (as produced by commonware-codec’s Encode impl on [PrivateKey]).

After decryption the plaintext buffer is zeroized.

pub fn read_encrypted<R: BufRead>( ciphertext: R, passphrase: SecretString, ) -> Result<Self, SigningKeyError>

Reads a passphrase-encrypted signing key from an arbitrary std::io::Read.

pub fn write_to_file_encrypted<P: AsRef<Path>>( &self, path: P, passphrase: SecretString, ) -> Result<(), SigningKeyError>

Writes the signing key to path as a passphrase-encrypted age payload.

pub fn write_encrypted<W: Write>( &self, writer: W, passphrase: SecretString, ) -> Result<(), SigningKeyError>

Writes the signing key to an arbitrary std::io::Write as a passphrase-encrypted age payload. See Self::write_to_file_encrypted.

pub fn try_from_hex(hex: &str) -> Result<Self, SigningKeyError>

pub fn to_writer_unencrypted<W: Write>( &self, writer: W, ) -> Result<(), SigningKeyError>

Writes the signing key to writer as 0x-prefixed hex of the raw encoded ed25519 private key bytes.

pub fn public_key(&self) -> PublicKey